# Terminal Dungeon

`terminal_dungeon` is a raycasting library for your terminal! `pip install terminal_dungeon` to install and `python -m terminal_dungeon` to play.

![Terminal Dungeon Preview](preview.gif)

### Controls
------------
* `ctrl+c` to exit
* `t` to turn off textures
* `wasdqe` or arrow-keys to move

### References
--------------
This project wouldn't have been possible without the following valuable resources:

[Lode's Computer Graphics Tutorial](https://lodev.org/cgtutor/raycasting.html)

[PyRay - Python Raycasting Engine](https://github.com/oscr/PyRay)

[pygame-raycasting-experiment](https://github.com/crobertsbmw/pygame-raycasting-experiment/blob/master/raycast.py)
